@@ -2,6 +2,8 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 import logging
+import os
+import sys
 from datetime import datetime
 
 from flask import render_template, Response
@@ -33,10 +35,14 @@ import puppetboard.errors  # noqa: F401
 
 from puppetboard.core import get_app, get_puppetdb
 from puppetboard.version import __version__
-from puppetboard.utils import check_db_version
+from puppetboard.utils import is_a_test, check_db_version, check_secret_key
 
 app = get_app()
 puppetdb = get_puppetdb()
+running_as = os.path.basename(sys.argv[0])
+if not is_a_test():
+    check_db_version(puppetdb)
+check_secret_key(app.config.get('SECRET_KEY'))
 
 logging.basicConfig(level=app.config['LOGLEVEL'].upper())
 log = logging.getLogger(__name__)
@@ -72,7 +78,27 @@ def utility_processor():
     def version():
         return __version__
 
-    return dict(now=now, version=version)
+    def fact_os_detection(os_facts):
+        os_name = ""
+        os_family = os_facts['family']
+
+        try:
+            if os_family == "windows":
+                os_name = os_facts["windows"]["product_name"]
+            elif os_family == "Darwin":
+                os_name = os_facts["macosx"]["product"]
+            else:
+                os_name = os_facts["distro"]["description"]
+        except KeyError:
+            pass
+
+        return os_name
+
+    return dict(
+        now=now,
+        version=version,
+        fact_os_detection=fact_os_detection,
+    )
 
 
 @app.route('/offline/<path:filename>')
@@ -90,8 +116,3 @@ def offline_static(filename):
 @app.route('/status')
 def health_status():
     return 'OK'
-
-
-@app.before_first_request
-def before_first_request():
-    check_db_version(puppetdb)
