@@ -1,4 +1,6 @@
+import json
 import os
+import secrets
 import tempfile
 import base64
 import binascii
@@ -58,10 +60,7 @@ PUPPETDB_CERT = cert_to_file(os.getenv('PUPPETDB_CERT', None))
 PUPPETDB_PROTO = os.getenv('PUPPETDB_PROTO', None)
 PUPPETDB_TIMEOUT = int(os.getenv('PUPPETDB_TIMEOUT', '20'))
 DEFAULT_ENVIRONMENT = os.getenv('DEFAULT_ENVIRONMENT', 'production')
-SECRET_KEY = os.getenv('SECRET_KEY', os.urandom(24))
-DEV_LISTEN_HOST = os.getenv('DEV_LISTEN_HOST', '127.0.0.1')
-DEV_LISTEN_PORT = int(os.getenv('DEV_LISTEN_PORT', '5555'))
-DEV_COFFEE_LOCATION = os.getenv('DEV_COFFEE_LOCATION', 'coffee')
+SECRET_KEY = os.getenv('SECRET_KEY', f"default-{secrets.token_hex(32)}")
 UNRESPONSIVE_HOURS = int(os.getenv('UNRESPONSIVE_HOURS', '2'))
 ENABLE_QUERY = coerce_bool(os.getenv('ENABLE_QUERY'), True)
 # Uncomment to restrict the enabled PuppetDB endpoints in the query page.
@@ -104,9 +103,9 @@ GRAPH_TYPE = os.getenv('GRAPH_TYPE', 'pie')
 # export INVENTORY_FACTS="Hostname, fqdn, IP Address, ipaddress,.. etc"
 # Define default array of of strings, this code is a bit neater than having
 # a large string
-INVENTORY_FACTS_DEFAULT = ','.join(['Hostname', 'fqdn',
-                                    'IP Address', 'ipaddress',
-                                    'OS', 'lsbdistdescription',
+INVENTORY_FACTS_DEFAULT = ','.join(['Hostname', 'trusted',
+                                    'IP Address', 'networking',
+                                    'OS', 'os',
                                     'Architecture', 'hardwaremodel',
                                     'Kernel Version', 'kernelrelease',
                                     'Puppet Version', 'puppetversion'])
@@ -115,6 +114,23 @@ INVENTORY_FACTS_DEFAULT = ','.join(['Hostname', 'fqdn',
 # array: ['Key', 'Value']
 INV_STR = os.getenv('INVENTORY_FACTS', INVENTORY_FACTS_DEFAULT).split(',')
 
+# To render jinja template we expect env var to be JSON
+INVENTORY_FACT_TEMPLATES = {
+    'trusted': (
+        """<a href="{{url_for('node', env=current_env, node_name=value.certname)}}">"""
+        """{{value.hostname}}"""
+        """</a>"""
+    ),
+    'networking': """{{ value.ip }}""",
+    'os': "{{ fact_os_detection(value) }}",
+}
+
+INV_TPL_STR = os.getenv('INVENTORY_FACT_TEMPLATES')
+
+if INV_TPL_STR:
+    INVENTORY_FACT_TEMPLATES = json.loads(INV_TPL_STR)
+
+
 # Take the Array and convert it to a tuple
 INVENTORY_FACTS = [(INV_STR[i].strip(),
                     INV_STR[i + 1].strip()) for i in range(0, len(INV_STR), 2)]
@@ -128,3 +144,10 @@ WITH_EVENT_NUMBERS = coerce_bool(os.getenv('WITH_EVENT_NUMBERS'), True)
 
 SHOW_ERROR_AS = os.getenv('SHOW_ERROR_AS', 'friendly')
 CODE_PREFIX_TO_REMOVE = os.getenv('CODE_PREFIX_TO_REMOVE', '/etc/puppetlabs/code/environments')
+FAVORITE_ENVS_DEF = ','.join([
+    'production',
+    'staging',
+    'qa',
+    'dev',
+])
+FAVORITE_ENVS = [x.strip() for x in os.getenv('FAVORITE_ENVS', FAVORITE_ENVS_DEF).split(',')]
