@@ -1,11 +1,9 @@
 import ast
 import json
 import logging
-import os.path
 import sys
 
 from flask import abort, request, url_for
-from jinja2.utils import pass_context
 from packaging.version import parse
 from pypuppetdb.errors import EmptyResponseError
 from requests.exceptions import ConnectionError, HTTPError
@@ -13,14 +11,6 @@ from requests.exceptions import ConnectionError, HTTPError
 log = logging.getLogger(__name__)
 
 
-@pass_context
-def url_static_offline(context, value):
-    request_parts = os.path.split(os.path.dirname(context.name))
-    static_path = '/'.join(request_parts[1:])
-
-    return url_for('static', filename="%s/%s" % (static_path, value))
-
-
 def url_for_field(field, value):
     args = request.view_args.copy()
     args.update(request.args.copy())
@@ -29,7 +19,7 @@ def url_for_field(field, value):
 
 
 def jsonprint(value):
-    return json.dumps(value, indent=2, separators=(',', ': '))
+    return json.dumps(value, indent=2, separators=(",", ": "))
 
 
 def check_db_version(puppetdb):
@@ -40,8 +30,8 @@ def check_db_version(puppetdb):
         current_version = puppetdb.current_version()
         log.info(f"PuppetDB version: {current_version}")
 
-        current_semver = current_version.split('-')[0]
-        minimum_semver = '5.2.0'
+        current_semver = current_version.split("-")[0]
+        minimum_semver = "5.2.0"
 
         if parse(current_semver) < parse(minimum_semver):
             log.error(f"The minimum supported version of PuppetDB is {minimum_semver}")
@@ -58,6 +48,28 @@ def check_db_version(puppetdb):
         sys.exit(2)
 
 
+def check_secret_key(secret_key_value):
+    """
+    Check if the secret key value is set to a default value, that will stop
+    being accepted in v5.x of the app.
+    """
+
+    if type(secret_key_value) is str and secret_key_value.startswith("default-"):
+        log.warning(
+            "Leaving SECRET_KEY set to a default value WILL cause issues"
+            " when the app is restarted or has more than 1 replica"
+            " (f.e. uWSGI workers, k8s replicas etc.) and some features"
+            " (in particular: queries) are used.\n"
+            "Please set SECRET_KEY to your own value, the same for all app"
+            " replicas.\n"
+            "This will be REQUIRED starting with Puppetboard 5.x which"
+            " will NOT contain the default value anymore.\n"
+            "Please see"
+            " https://github.com/voxpupuli/puppetboard/issues/721"
+            " for more info."
+        )
+
+
 def parse_python(value: str):
     """
     :param value: any string, number, bool, list or a dict
@@ -87,8 +99,7 @@ def formatvalue(value):
 
 
 def get_or_abort(func, *args, **kwargs):
-    """Perform a backend request and handle all the errors,
-    """
+    """Perform a backend request and handle all the errors,"""
     return _do_get_or_abort(False, func, *args, **kwargs)
 
 
@@ -149,9 +160,17 @@ def quote_columns_data(data: str) -> str:
     interpret the dot a way to get into a nested results object.
 
     See https://datatables.net/reference/option/columns.data#Types."""
-    return data.replace('.', '\\.')
+    return data.replace(".", "\\.")
 
 
-def check_env(env, envs):
-    if env != '*' and env not in envs:
+def check_env(env: str, envs: dict):
+    if env != "*" and env not in envs:
         abort(404)
+
+
+def is_a_test():
+    running_in_shell = any(
+        pytest_binary in sys.argv[0] for pytest_binary in ["pytest", "py.test"]
+    )
+    running_in_intellij = any("_jb_pytest_runner.py" in arg for arg in sys.argv)
+    return running_in_shell or running_in_intellij
